# calendar

This is an extension for juntagrico. You can find more information about juntagrico here
(https://github.com/juntagrico/juntagrico)

For more information information about how to install this app hop over to the doc section of the repo.